summaryrefslogtreecommitdiff
path: root/nuttx/fs/nfs/nfs_mount.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-03-28 23:27:24 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-03-28 23:27:24 +0000
commit3e62f2be816d0a212b52fd609121004b16d80a8a (patch)
tree4a3dd57f16aca637a553cc076b74af38dea9f9df /nuttx/fs/nfs/nfs_mount.h
parent1ad0258bca015406a52a0da9c9c13b2d19200864 (diff)
downloadpx4-nuttx-3e62f2be816d0a212b52fd609121004b16d80a8a.tar.gz
px4-nuttx-3e62f2be816d0a212b52fd609121004b16d80a8a.tar.bz2
px4-nuttx-3e62f2be816d0a212b52fd609121004b16d80a8a.zip
NFS update
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@4538 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/fs/nfs/nfs_mount.h')
-rw-r--r--nuttx/fs/nfs/nfs_mount.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/nuttx/fs/nfs/nfs_mount.h b/nuttx/fs/nfs/nfs_mount.h
index 107f4d966..9f6e9b340 100644
--- a/nuttx/fs/nfs/nfs_mount.h
+++ b/nuttx/fs/nfs/nfs_mount.h
@@ -51,10 +51,6 @@
* Pre-processor Definitions
****************************************************************************/
-#define NFSOP(nmp, op) (*nmp->nm_nfsops->nn_##op)
-#define NFSHASOP(nmp, op) (nmp->nm_nfsops->nn_##op != NULL)
-#define NFSDAT(nmp, nam) (nmp->nm_nfsops->nn_##nam)
-
/* Convert mount ptr to nfsmount ptr. */
#define VFSTONFS(mp) ((struct nfsmount *)((mp)->i_private))
@@ -72,9 +68,11 @@ struct nfsmount
{
int nm_flag; /* Flags for soft/hard... */
int nm_state; /* Internal state flags */
- struct inode *nm_mountp; /* Vfs structure for this filesystem */
- struct nfsnode *nfs_head; /* A list to all files opened on this mountpoint */
- bool nfs_mounted; /* true: The file system is ready */
+ struct inode *nm_blkdriver; /* Vfs structure for this filesystem */
+ struct nfsnode *nm_head; /* A list to all files opened on this mountpoint */
+ bool nm_mounted; /* true: The file system is ready */
+ sem_t nm_sem; /* Used to assume thread-safe access */
+ nfstype nfsv3_type; /* File type */
int nm_numgrps; /* Max. size of groupslist */
nfsfh_t nm_fh; /* File handle of root dir */
int nm_fhsize; /* Size of root file handle */
@@ -101,6 +99,7 @@ struct nfsmount
int nm_acregmin; /* Reg file attr cache min lifetime */
int nm_acregmax; /* Reg file attr cache max lifetime */
unsigned char nm_verf[NFSX_V3WRITEVERF]; /* V3 write verifier */
+ uint8_t *nm_buffer; /* This is an allocated buffer to hold one sector*/
};
/****************************************************************************